summaryrefslogtreecommitdiffstats
path: root/kmdi/kmdichildarea.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmdi/kmdichildarea.h')
-rw-r--r--kmdi/kmdichildarea.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmdi/kmdichildarea.h b/kmdi/kmdichildarea.h
index 37ce3336f..dac64cff4 100644
--- a/kmdi/kmdichildarea.h
+++ b/kmdi/kmdichildarea.h
@@ -154,31 +154,31 @@ public:
/**
* Sets the MDI childframe window caption font
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionFont( const TQFont &fnt );
/**
* Sets the foreground color of the active MDI childframe window caption
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionActiveForeColor( const TQColor &clr );
/**
* Sets the background color of the active MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionActiveBackColor( const TQColor &clr );
/**
* Sets the foreground color of inactive MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionInactiveForeColor( const TQColor &clr );
/**
* Sets the background color of inactive MDI childframe window captions
- * A relayout does not occur when using this function
+ * A retqlayout does not occur when using this function
*/
void setMdiCaptionInactiveBackColor( const TQColor &clr );
@@ -237,9 +237,9 @@ public slots:
void tileVertically();
/**
* Position and layout the minimized child frames
*/
- void layoutMinimizedChildren();
+ void tqlayoutMinimizedChildren();
protected:
@@ -249,7 +249,7 @@ protected:
void tileAllInternal( int maxWnds );
/**
- * Automatically resizes a maximized MDI view and layouts the positions of minimized MDI views.
+ * Automatically resizes a maximized MDI view and tqlayouts the positions of minimized MDI views.
*/
virtual void resizeEvent( TQResizeEvent * );
@@ -237,9 +237,9 @@ public slots:
void tileVertically();
/**
- * Position and layout the minimized child frames
+ * Position and tqlayout the minimized child frames
*/